@@ -154,7 +154,7 @@ compiler_target_opt() ->
 
 %% @doc Join options.
 fix_opts(Opts) ->
-  string:join(Opts, " ").
+  lists:flatten(lists:join(" ", Opts)).
 
 %% @doc Translate optimization-level flag (default is "O2").
 trans_optlev_flag(Tool, Options) ->
@@ -526,8 +526,8 @@ unique_folder(FunName, Arity, Options) ->
     case proplists:get_bool(llvm_save_temps, Options) of
       true ->  %% Store folder in current directory
         DirName;
-      false -> %% Temporarily store folder in tempfs (/dev/shm/)
-        "/dev/shm/" ++ DirName
+      false -> %% Temporarily store folder in tempfs or tmp dir
+        tmpfs_folder() ++ DirName
     end,
   %% Make sure it does not exist
   case dir_exists(Dir) of
@@ -537,6 +537,14 @@ unique_folder(FunName, Arity, Options) ->
       Dir
   end.
 
+tmpfs_folder() ->
+  case os:type() of
+    {unix, linux} ->
+      "/dev/shm/";
+    {unix, _} -> %% Fallback to tmp dir. e.g. FreeBSD
+      "/tmp/"
+  end.
+
 %% @doc Function that checks that a given Filename is an existing Directory
 %%      Name (from http://rosettacode.org/wiki/Ensure_that_a_file_exists#Erlang)
 dir_exists(Filename) ->
